<?php
/**
 *
 * Simple Block Gest. An extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2017, Galandas, http://phpbb3world.altervista.org
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace galandas\blockgest\acp;

/**
 * Simple Block Gest ACP module.
 */
class blockgest_module
{
	public $page_title;
	public $tpl_name;
	public $u_action;

	public function main($id, $mode)
	{
		global $db, $user, $template, $request, $phpbb_container;
		
		$table_blockgest = $phpbb_container->getParameter('galandas.blockgest.table.blockgest');

		$user->add_lang_ext('galandas/blockgest', 'common');
		
		// Set up general vars
		$action = $request->variable('action', '');
		$action = (isset($_POST['add'])) ? 'add' : ((isset($_POST['save'])) ? 'save' : $action);
		
		$this->tpl_name = 'acp_block_conf';
		$this->page_title = $user->lang('ACP_BLOCK_TITLE');
		
		$form_name = 'acp_block_conf';
		add_form_key($form_name);

		switch ($action)
		{
			case 'edit':

				$block_id = $request->variable('id', 0);
				$block_enabled = $request->variable('block_enabled', 0);

				if (!$block_id)
				{
					trigger_error($user->lang['ACP_BLOCK_NIX'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				$sql = 'SELECT block_name, block_cont, block_enabled
					FROM ' . $table_blockgest . "
					WHERE block_id = $block_id";
				$result = $db->sql_query($sql);
				$block_info = $db->sql_fetchrow($result);
				$db->sql_freeresult($result);
				
				$s_hidden_fields .= '<input type="hidden" name="id" value="' . $block_id . '" />';

			case 'add':

				$template->assign_vars(array(
					'S_EDIT_BLOCK'		=> true,
					'U_ACTION'			=> $this->u_action,
					'U_BACK'			=> $this->u_action,
					'BLOCK_NAME'		=> (isset($block_info['block_name'])) ? $block_info['block_name'] : '',
					'BLOCK_CONT'		=> (isset($block_info['block_cont'])) ? $block_info['block_cont'] : '',
					'BLOCK_ENABLED'		=> (isset($block_info['block_enabled'])) ? $block_info['block_enabled'] : '',
					'S_HIDDEN_FIELDS'	=> $s_hidden_fields)
				);

				return;

			break;

			case 'save':

				if (!check_form_key($form_name))
				{
					trigger_error($user->lang['FORM_INVALID']. adm_back_link($this->u_action), E_USER_WARNING);
				}

				$block_id		= $request->variable('id', 0);
				$block_name		= $request->variable('block_name', '', true);
				$block_cont		= htmlspecialchars_decode(utf8_normalize_nfc($request->variable('block_cont', '', true)));
				$block_enabled		= $request->variable('block_enabled', 0);

				if ($block_name === '' || $block_cont === '' || $block_enabled === '')
				{
					trigger_error($user->lang['ACP_BLOCK_ERROR'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				$sql_ary = array(
					'block_name'	=> $block_name,
					'block_cont'	=> $block_cont,
					'block_enabled'	=> $block_enabled
				);

				if ($block_id)
				{
					$db->sql_query('UPDATE ' . $table_blockgest . ' SET ' . $db->sql_build_array('UPDATE', $sql_ary) . ' WHERE block_id = ' . $block_id);
				}
				else
				{
					$db->sql_query('INSERT INTO ' . $table_blockgest . ' ' . $db->sql_build_array('INSERT', $sql_ary));
				}

				$message = ($block_id) ? $user->lang['ACP_BLOCK_UPDATED'] : $user->lang['ACP_BLOCK_ADDED'];
				trigger_error($message . adm_back_link($this->u_action));

			break;

			case 'delete':

				$block_id = $request->variable('id', 0);

				if (!$block_id)
				{
					trigger_error($user->lang['ACP_BLOCK_NIX'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				if (confirm_box(true))
				{
					$sql = 'SELECT block_name
						FROM ' . $table_blockgest . "
						WHERE block_id = $block_id";
					$result = $db->sql_query($sql);
					$deleted_block_name = $db->sql_fetchfield('block_name');
					$db->sql_freeresult($result);

					$sql = 'DELETE FROM ' . $table_blockgest . "
						WHERE block_id = $block_id";
					$db->sql_query($sql);

					trigger_error($user->lang['ACP_BLOCK_REMOVED'] . adm_back_link($this->u_action));
				}
				else
				{
					confirm_box(false, $user->lang['CONFIRM_OPERATION'], build_hidden_fields(array(
						'i'			=> $id,
						'mode'		=> $mode,
						'id'		=> $block_id,
						'action'	=> 'delete',
					)));
				}

			break;
		}

		$template->assign_vars(array(
			'U_ACTION'			=> $this->u_action,
			'S_HIDDEN_FIELDS'	=> $s_hidden_fields)
		);

		$sql = 'SELECT *
			FROM ' . $table_blockgest . '
			ORDER BY block_id';
		$result = $db->sql_query($sql);

		while ($row = $db->sql_fetchrow($result))
		{
			$template->assign_block_vars('block', array(
				'BLOCK_ID'			=> $row['block_id'],
				'BLOCK_NAME'		=> $row['block_name'],
				'BLOCK_CONT'		=> $row['block_cont'],
				'BLOCK_ENABLED'		=> $row['block_enabled'],
				'U_EDIT'			=> $this->u_action . '&amp;action=edit&amp;id=' . $row['block_id'],
				'U_DELETE'			=> $this->u_action . '&amp;action=delete&amp;id=' . $row['block_id'])
			);
		}
		$db->sql_freeresult($result);
	}
}
